package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````Y!4``#0```!(D0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````]'T`
M`/1]```%```````!``$```#`C0``P(T!`,"-`0!\`@``K!(```8```````$`
M`@```,B-``#(C0$`R(T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3`C0``P(T!`,"-`0!``@``0`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$\````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3P```%````!4````
M60```%H```!A````8@```&,`````````90```&8`````````9P```&@```!K
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````@!`````````#``<```````"0`0```````P`1``$`````
M`````````!(```#F`0`````````````2````"0``````````````$0````P"
M`````````````!$```"(`0`````````````2````$```````````````$@``
M`,4!`````````````!(````8```````````````2````'P``````````````
M$@```!D"`````````````!(```#1`0`````````````2````*```````````
M````(````$T#`````````````"$```!````````````````2````1@``````
M````````$@```$T``````````````!(````:`P`````````````2````"P,`
M````````````$@```+4"`````````````!(```!4```````````````2````
M5@(`````````````$@```%L``````````````!(```#J`@`````````````2
M````8@``````````````$@```&H``````````````!(```#3`@``````````
M```2````<@``````````````$@```'L``````````````"`````$`P``````
M```````2````EP``````````````$@```)P``````````````!(````J`@``
M```````````1````\0(`````````````$@```(,"`````````````!(```"C
M```````````````2````=0(`````````````$@```)$#`````````````!(`
M``!,`P`````````````1````IP(`````````````$@```#D#````````````
M`!(````U`@`````````````2````3@,`````````````$0```*H`````````
M`````!(````Q`P`````````````2````LP``````````````$0```)8!````
M`````````!(```#%```````````````B````U```````````````(````.H`
M`````````````!(```#\`@`````````````2````DP(`````````````$@``
M`.\``````````````!(```#U```````````````@````W@(`````````````
M$@````\!`````````````!(```"V`0`````````````2````%`$`````````
M````$@```,,"`````````````!(````:`0`````````````2````I0$`````
M````````$@```"@!`````````````!(````Y`0`````````````2````40(`
M````````````$@```&("`````````````!(````_`0`````````````2````
MG`(`````````````$@```"H#`````````````!(```!.`0`````````````2
M````(@,`````````````$@```&(!`````````````!(```!,`@``````````
M```2````]`$`````````````$@```&D!`````````````!(```!P`0``````
M```````2````2P,`````````````(0```($!`````````````!(```"1!```
M;*`!```````0`!(`1@,``)03``!0`@``$@`)``8"``!X/P``!````!(`"@#3
M`P``:"8```0'```2``D`H00``/@P``!8````$@`)`+`#``"D'P``!````!(`
M"0!%!```@!````0````2``<`]@,``&PM``",`P``$@`)`$L$```\D`$`````
M`!``$@!Y!```J!\``#`"```2``D`+@0``#R0`0``````$``2`,$#``"T)0``
MM````!(`"0#@`P``B!T``%P````2``D`Z`,``#0E``!H````$@`)``P$``#\
M/```1`$``!(`"0`A!```V"$``!P````2``D`.@0``&R@`0``````$``2`)P$
M``!LH`$``````!``$@!V`P``"!8``&0````2``D`600``/0A```(`0``$@`)
M`!<$```XD`$`!````!$`$0!R!```/)`!```````0`!$`,P0``.05````````
M$@`)`$($``"L/```4````!(`"0!_`P``G"4``!@````2``D`F@,``%`>``!4
M`0``$@`)`(8$``!`/@``.`$``!(`"0"0!```;*`!```````0`!(`900``/PB
M```X`@``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R
M:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`
M<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R
M96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I
M9FEC`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!097)L7V-R;V%K
M7VUE;6]R>5]W<F%P`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I
M<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?
M7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM87)M:&8N<V\N,0!?<W1A
M<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E
M>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A<E]P;`!P87)?8F%S96YA;64`
M7U]B<W-?<W1A<G0`7U]E;F1?7P!S:&%?:6YI=`!?7V)S<U]S=&%R=%]?`'!A
M<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H
M85]F:6YA;`!?7V)S<U]E;F1?7P!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%``#`C0$`%P```,2-`0`7````P(\!`!<`
M``#,CP$`%P```-B/`0`7`````)`!`!<````(D`$`%P````R0`0`7````%)`!
M`!<````8D`$`%P```!R0`0`7````()`!`!<````DD`$`%P```"R0`0`7````
M,)`!`!<````XD`$`%P```,2/`0`5!0``R(\!`!4&``#0CP$`%0X``-2/`0`5
M'@``W(\!`!4B``#@CP$`%2P``.2/`0`5+P``Z(\!`!4Q``#LCP$`%3(``/"/
M`0`5-P``](\!`!4\``#XCP$`%3X``/R/`0`50@``Q(X!`!8#``#(C@$`%@0`
M`,R.`0`6!P``T(X!`!8(``#4C@$`%@D``-B.`0`6"@``W(X!`!8+``#@C@$`
M%@P``.2.`0`6#0``Z(X!`!8.``#LC@$`%A```/".`0`6$0``](X!`!82``#X
MC@$`%A,``/R.`0`6%````(\!`!85```$CP$`%A8```B/`0`6%P``#(\!`!88
M```0CP$`%AD``!2/`0`6&@``&(\!`!8;```<CP$`%AP``""/`0`6'0``)(\!
M`!8?```HCP$`%B```"R/`0`6(0``,(\!`!8C```TCP$`%B0``#B/`0`6)0``
M/(\!`!8F``!`CP$`%B<``$2/`0`6*0``2(\!`!8J``!,CP$`%BL``%"/`0`6
M+0``5(\!`!8N``!8CP$`%C```%R/`0`6,0``8(\!`!8R``!DCP$`%C,``&B/
M`0`6-```;(\!`!8U``!PCP$`%C8``'2/`0`6.```>(\!`!8Y``!\CP$`%CH`
M`("/`0`6.P``A(\!`!8]``"(CP$`%C\``(R/`0`60```D(\!`!9!``"4CP$`
M%D,``)B/`0`61```G(\!`!9%``"@CP$`%D8``*2/`0`61P``J(\!`!9(``"L
MCP$`%DD``+"/`0`62@``M(\!`!9+``"XCP$`%DP``+R/`0`63@```4`MZ0%`
MO>@>_R_A!.`MY03@G^4.X(_@"/"^Y1Q^`0``QH_B%\J,XAS^O.4`QH_B%\J,
MXA3^O.4`QH_B%\J,X@S^O.4`QH_B%\J,X@3^O.4`QH_B%\J,XOS]O.4`QH_B
M%\J,XO3]O.4`QH_B%\J,XNS]O.4`QH_B%\J,XN3]O.4`QH_B%\J,XMS]O.4`
MQH_B%\J,XM3]O.4`QH_B%\J,XLS]O.4`QH_B%\J,XL3]O.4`QH_B%\J,XKS]
MO.4`QH_B%\J,XK3]O.4`QH_B%\J,XJS]O.4`QH_B%\J,XJ3]O.4`QH_B%\J,
MXIS]O.4`QH_B%\J,XI3]O.4`QH_B%\J,XHS]O.4`QH_B%\J,XH3]O.4`QH_B
M%\J,XGS]O.4`QH_B%\J,XG3]O.4`QH_B%\J,XFS]O.4`QH_B%\J,XF3]O.4`
MQH_B%\J,XES]O.4`QH_B%\J,XE3]O.4`QH_B%\J,XDS]O.4`QH_B%\J,XD3]
MO.4`QH_B%\J,XCS]O.4`QH_B%\J,XC3]O.4`QH_B%\J,XBS]O.4`QH_B%\J,
MXB3]O.4`QH_B%\J,XAS]O.4`QH_B%\J,XA3]O.4`QH_B%\J,X@S]O.4`QH_B
M%\J,X@3]O.4`QH_B%\J,XOS\O.4`QH_B%\J,XO3\O.4`QH_B%\J,XNS\O.4`
MQH_B%\J,XN3\O.4`QH_B%\J,XMS\O.4`QH_B%\J,XM3\O.4`QH_B%\J,XLS\
MO.4`QH_B%\J,XL3\O.4`QH_B%\J,XKS\O.4`QH_B%\J,XK3\O.4`QH_B%\J,
MXJS\O.4`QH_B%\J,XJ3\O.4`QH_B%\J,XIS\O.4`QH_B%\J,XI3\O.4`QH_B
M%\J,XHS\O.4`QH_B%\J,XH3\O.4`QH_B%\J,XGS\O.4`QH_B%\J,XG3\O.4`
MQH_B%\J,XFS\O.4`QH_B%\J,XF3\O.4`QH_B%\J,XES\O.4`QH_B%\J,XE3\
MO.4`QH_B%\J,XDS\O.4`QH_B%\J,XD3\O.4`QH_B%\J,XCS\O.4`QH_B%\J,
MXC3\O.4`QH_B%\J,XBS\O.4P0"WI)-!-XAP`C>48$(WE%""-Y1@0C>(4((WB
M'`"-XN1!G^6G___KX#&?Y01`C^`#,)3G##"-Y=0QG^4,()WE`S"4YP(0H.$#
M`*#A$#"-Y5?__^N\,9_E`S"4YP!0T^6T,9_E``!5XP-`E.<+```:=O__ZZ0A
MG^4``%#C`B"/X!``@N4!```:`0"@XY;__^NG___K``"4Y<#__^M]5\#E``"4
MY;W__^O.,]#E`C"#X\XSP.4``)3EN/__Z\XST.4!,(/CSC/`Y1P`G>4%`(#B
M!P%PXP```)IQ___K``&@X8W__^L`$*#A&,"=Y3`QG^4`()SE`S"/X``@@.4D
M(9_E"`"#Y0(@C^`$((#E&"&?Y0(@C^``()+E"""`Y0PAG^4"((_@#""AY00@
MH.,$((/E`3"@XQP@G>4#`%+A+@``R@`PH.,-$8+BY%"?Y0$Q@.?@$)_E`#"-
MY050C^``,*#A`R""XA``E>4!$(_@*/__ZP!`4.("```:$`"5Y6#__^L`0*#A
ML%"?Y050C^`0`)7E/?__ZZ0`G^4``(_@TP``ZP``4.,,```:##"5Y0``4^,#
M```:B`"?Y0``C^#+``#K#`"%Y7PPG^4#,(_@#`"3Y0``4.,````*X08`ZV@P
MG^4#,(_@$`"3Y77__^O,_O_K!`"@X230C>(P@+WH`^&<YP$P@^($X*'ERO__
MZO!Z`0!$`0``0`$``!`!```D`0``0'P!`,A[`0`G+@``C'L!``XN``!D>P$`
MX`@``#1[`0"?*P``-"L``/1Z`0#<>@$``+"@XP#@H.,0$)_E`1"/X`T`H.$/
MP,#C#-"@X0```.O0=P$`'T`MZ4@PG^5(()_E`S"/X`(@D^<(((WE/""?Y0(@
MD^<,((WE`""@XP0@C>4L()_E`C"3YP0@@.(`,(WE`!"0Y0@PG>4,`)WE]?[_
MZQ30C>($\)WDG'@!`"`!```(`0``%`$``"P`G^4L,)_E``"/X`,PC^```%/A
M(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^'`>0$`O'D!`"QX`0`<
M`0``.`"?Y3@0G^4``(_@`1"/X``00>"A/Z#A01&#X"0PG^7!$+#A`S"/X![_
M+P$8()_E`C"3YP``4^,>_R\!$_\OX7QY`0!X>0$`W'<!`#@!``!H,)_E$$`M
MZ0,PC^``,-/E7$"?Y0``4^,$0(_@$("]&%`PG^4#,)3G``!3XP(```I$,)_E
M`P"?Y\K^_^O*___K.#"?Y0,PE.<``%/C`@``"BP`G^4``(_@:_[_ZP$@H.,@
M,)_E`S"/X``@P^40@+WH+'D!`)AW`0`P`0``Q'@!`!@!``"49@``T'@!`#0P
MG^4T()_E`S"/X`(PD^<``%/C!P``"A!`+>D@$)_E(`"?Y0$0C^```(_@K?[_
MZQ!`O>BZ___JN?__ZAQW`0`T`0``B'@!`#1F``"<,)_E\$<MZ0!04.(#,(_@
M!4"@`2````J(()_E`C"3YP!`D^4``%3C&P``"@&0H.$%,*#A`V"@X0$@T^0`
M`%+C/0!2$_K__QH$@*#A!6!&X`APH.$$H)CD``!:XPI`H`$-```*!B"@X040
MH.$*`*#A4_[_ZP``4./T__\:!C#:YST`4^/Q__\:!'!'X$=QH.$!0(;B`'")
MY01`BN`$`*#A\(>]Z,QV`0`H`0``!T`MZ4P@G^5,,)_E`B"/X`,PDN<-$*#A
M`#"3Y00PC>4`,*#CRO__ZS`@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``
M,*#C````"JG^_^L,T(WB!/"=Y"!V`0`L`0``_'4!`'-`+>F0()_ED#"?Y0(@
MC^`#,)+G`$"@X0`PD^4$,(WE`#"@XPU@H.%T4)_E!5"/X`80H.$$`*#AK/__
MZP``4.,)```:7""?Y5`PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,*```*
MB?[_ZS@PG^4`()WE`S"5YP`PD^4",8/@!""3Y0``4N,$((/D^___&N;__^H(
MT(WB<("]Z+QU`0`L`0``G'4!`'QU`0`H`0``\$<MZ4`AG^5`,9_E`B"/X`,P
MDN>@T$WB`%!0X@`PD^6<,(WE`#"@XQ,```H`,-7E``!3XQ````JR_?_K`&!0
MX@T```H(<9_E"(&?Y0B1G^4'<(_@"("/X`F0C^`&`*#AS_W_ZP!`4.(-```:
M!@"@X>G]_^L%`*#A+_[_Z]P@G^7(,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``
M,*#C*```"D_^_^L30(3B!Q"@X00`H.&X_?_K``!0X^?__PH($*#A!`"@X;/]
M_^L``%#CXO__"@4`H.$__O_K`*"@X00`H.$\_O_K``"*X`(`@.*^_?_K`*"@
MX00PH.$%(*#A"1"@X2C^_^L-$*#A"@"@X0W^_^L!`'#C"@"@X0<```H0,)WE
M#SH#X@$)4^,#```:L___ZPH`H.$,_O_KQ___ZJ?]_^OZ___JH-"-XO"'O>@,
M=0$`+`$``$\F``!*)@``228``)1T`0`00"WIB""?Y8@PG^4"((_@H-!-X@,P
MDN<-$*#A`$"@X0`PD^6<,(WE`#"@X_C]_^L``%#C``"@$PD``!H0,)WE#SH#
MX@H*4^,!"5,3!```&@(0H.,$`*#A8/W_ZQ`/;^&@`J#A,""?Y2@PG^4"((_@
M`S"2YP`@D^6<,)WE`B`SX``PH.,````*_/W_ZZ#0C>(0@+WHJ',!`"P!``!(
M<P$`\$\MZ0%0H.'$(9_EQ#&?Y0(@C^`#,)+G%-!-X@`PD^4,,(WE`#"@XP`P
MT>4`8*#A/0!3XP%0@0(%`*#AY/W_ZP@0C>(`<*#A!@"@X?K^_^N$D9_E`$!0
MX@F0C^`1```*V_W_ZP``5^$F``"*`4!$X@$PU>0``%/C`3#DY?O__QI8(9_E
M3#&?Y0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XTD```K-_?_K-#&?Y0.@F><`
ML)KE!#&;YP``4^,S```:(#&?Y0*`A.(#,(_@`""3Y0B!H.$``%+C+@``"@@0
MH.$+`*#A#_W_ZP``4.,``(KEXO__"@`PFN4(@(/@`#"@XP0P".4(0(WE!C"@
MX0,`H.$!(-/D``!2XST`4A/Z__\:O#"?Y08`0.`#0)GG`G"'X@<`@.`(D)WE
M`("4Y2G]_^L``%#C"0&(Y\S__PH`,)3E"""=Y0(AD^<!$-;D`C"@X0``4>,]
M`%$3`!#"Y0$@@N+X__\:/2"@XP`@P^4!(-7D``!2XP$@X^7[__\:N___Z@%`
MA.+&___J`2"@XP@`H.$`((/E#_W_ZP`P4.($,(WELO__"@L0H.$(($CB#/W_
MZP0PG>4`,(KER?__ZA30C>+PC[WH!',!`"P!``"\<@$`C'(!`"@!``#L<P$`
M$T`MZ3Q`G^4\,)_E!$"/X`,PE.<``)/E8_W_ZRPPG^4L$)_E`S"4YP$0C^`$
M,(WE(#"?Y00@G>4#,(_@"-"-XA!`O>A2_?_J''$!`"0!```\`0``CR(``&I?
M```30"WI3#"?Y4P@G^4#,(_@`D"3YP``E.5,_?_KX/__ZP``E.5)_?_K`""@
MXRPPG^4$((WE*!"?Y2@@G^4#,(_@`#"-Y0(@C^`!$(_@K_S_ZPC0C>(0@+WH
MP'`!`"0!``">)```+R(``#P/``!P0"WI,!&?Y3`AG^4"VDWB&-!-X@$0C^`"
M()'G`CJ-XA0P@^(`()+E`""#Y0`@H..G_/_K""&?Y0AAG^4"((_@`""-Y0`A
MG^4,0(WB`#"@X080H.$$`*#A`B"/X(W\_^L!,(#B!@!3X0```)KP`/#G`0!P
MXPP``!H`,*#CS`"?Y;@0G^4``(_@`BJ-X@$0D.<4((+B``"1Y0`0DN4``#'@
M`!"@XR````H?_?_K`5J-XA!0A>($`*#A`2J@XP40H.'+_/_K`$!0XNK__[H!
M`(3BE_S_ZP`P4.+F__\*!0!3X0(``"H$((/@`@!5X=[__SH%`%/A`@``F@0@
MA>`"`%/AV?__.@8`5.'7___*!""@X0,`H.$%$*#A]_S_ZP`@H.,`,*#A!"#`
MY]/__^H#`*#A`MJ-XAC0C>)P@+WH3'`!`"P!``#P(0```1```,@A``#<;P$`
MJ?__ZO!/+>D!4*#A\!&?Y?`AG^5"W4WB`1"/X#303>(`0*#AX`&?Y0(@D>="
M/8WB``"/X"PP@^(`()+E`""#Y0`@H.,E_O_K+Q"@XP!@H.$$`*#A?_S_ZP``
M4.,/```*J`&?Y000H.$``(_@X?[_ZYP1G^6,(9_E`1"/X$(]C>("()'G+#"#
MX@`0DN4`()/E`1`RX``@H.-5```*S?S_ZP0`H.'(_/_K:!&?Y0P`C>4!$(_@
M!0"@X;'\_^L`<*#A5)&?Y52AG^54L9_E"9"/X`J@C^`+L(_@``!7X]___PH`
M(-?E``!2XPEPH`$``%;C"0``"@<0H.$&`*#A(OS_ZP``4.,$```:&!&?Y0$0
MC^";_/_K`'"@X>[__^H'`*#AJ?S_ZP#`H.,``(?@!Q!`X`$@<.4O`%+C$0``
M"@PPG>4!((/B`2""X`$*4N/#__^JL("-X@102.(',*#A"B"@X0$:H.,%`*#A
M!$"-Y0"PC>7S^__K`0"`X@$*4.,"``":\`#PYP#`P.7G___J!0"@X1`0C>)H
M_/_K``!0XQ```!J0,!CE#SH#X@()4^,,```:`1"@XP4`H.'>^__K``!0XP<`
M`!I@`)_E!1"@X0``C^"(_O_K!0"@X0_\_^L`0*#AHO__ZD00G^4``*#C`1"/
MX,;__^H$`*#A0MV-XC30C>+PC[WH]&X!`"P!``"L(```?2```)1N`0!"(```
MQQ\``/`@```@(```YA\``!D?```&'P```#"@X0$@T^0``%+C'O\O`2\`4N,#
M`*`!^?__ZA!`+>D`0%#B`@``"@`PU.4``%/C`P``&M@`G^4``(_@$$"]Z.C[
M_^I3_/_K`0!`X@``A.```%3A`#"@X1L``"H`(-/E`0!`XB\`4N/X__\*`P!4
MX14``"H#(*#A`1!2Y"\`4>,/```:`3!#X@,`5.$#(*#A`P``*@`0TN4!,$/B
M+P!1X_C__PH$($+@`C""X@$*4^,5``"*`2""X@$*4N,,``":\`#PYP(PH.'G
M___J`P!4X>O__QH`,-3E+P!3XS0`GP4``(\`U/__"BP`G^4``(_@T?__ZB0P
MG^4$$*#A`S"/X`,`H.';^__K$("]Z```H.,0@+WH)QX``'\=``#4'0``D&T!
M`!!`+>G$(9_EQ#&?Y0(@C^`HT$WB`S"2YPT@H.&T$9_E`#"3Y20PC>4`,*#C
M`1"/X`HP@>(JP('B`N"@X0``D^4$$)/E"#"#X@,`KN@,`%/A#B"@X??__QJP
M,-/A>`&?Y;`PSN$``(_@7_W_ZVP!G^5L09_E``"/X%O]_^MD`9_E!$"/X```
MC^!7_?_K6`&?Y0``C^!4_?_K4`&?Y0``C^!1_?_K2`&?Y0``C^!._?_K0`&?
MY0``C^!+_?_K.`&?Y0``C^!(_?_K!`"@X4;]_^LH`9_E``"/X$/]_^L@`9_E
M``"/X$#]_^L8`9_E``"/X"3]_^L`$%#B`0``"@0`H.'F_?_K``&?Y0``C^`=
M_?_K`!!0X@(```KP`)_E``"/X-[]_^OH`)_E``"/X!7]_^L`$%#B$0``"M@`
MG^4``(_@UOW_Z]`0G^70`)_E`1"/X```C^#1_?_KQ""?Y7`PG^4"((_@`S"2
MYP`@D^4D,)WE`B`SX``PH.,2```*O_O_ZZ``G^4``(_@_OS_ZP`04.*4`)\5
M``"/$.C__QJ,$)_E"B"@XP$0C^`1`(WB._O_ZP``4./B__\:=`"?Y1L0C>(`
M`(_@W?__ZBC0C>(0@+WHJ&L!`"P!```"6@``.AT``#,=``!E'0``*QT``"@=
M```C'0``)QT``-`<```;'0``&QT``*T<```-'0```AT``/D;``#T'```2!P`
M`/P<``!O'```5&H!`*@<``!''```F1P``!L<```00"WI3#"?Y0,PC^``,)/E
M`0!SXPP``!H\`)_E``"/X,K\_^L``%#C!```"@``T.4P`%#C``!0$P$`H!,`
M`*`#&#"?Y0,PC^```(/E$#"?Y0,`G^<0@+WHP&H!`(<;``"$:@$`>&H!`!!`
M+>EX^__K&OO_ZP``4.,``)`5$("]Z/=`+>F8<)_E`$"@X0=PC^`'`*#AK?S_
MZP!04.($$*#A`@``"@`PU>4``%/C!```&G``G^4``(_@#-"-XO!`O>AH_?_J
M]OK_ZP``4.,2```:!`"@X5C[_^L`8*#A!0"@X57[_^L``(;@`@"`XM?Z_^L`
M8*#A,#"?Y3`0G^4$(*#A`1"/X`!0C>4#,(_@/OO_ZP80H.$'`*#AYO__Z@S0
MC>+P@+WHAAL``%X;``!:&@``,!L``/!/+>EP%I_E<":?Y8'<3>(DT$WB`1"/
MX&3&G^4"()'G@3R-XA).C>(,P(_@`""2Y1P@@^4`(*#C'#"#XA!0C.)T,$3B
M7.!$X@!@H.$'`)SI!P"#Z`\`M>@/`*[H`P"5Z&@P1.(HP(SB`P".Z`<`G.@'
M`(/H#`:?Y0QVG^4``(_@9?S_ZP!04.('<(_@%```"@`PU>4``%/C$0``"JK_
M_^OH%9_EU"6?Y0$0C^"!/(WB`B"1YQPP@^(`$)+E`""3Y0$0,N``(*#C````
M"A#[_^L%`*#A@=R-XB30C>+P3[WHG/K_ZI+__^L`4%#B:(!$`F8```H%`*#A
M`OO_ZX``H.$!`(#BA/K_ZP"0H.$`@*#A?*6?Y0%01>(*H(_@`2#UY0``4N-?
M```:7(!$X@10F.0``%7C#```"@4`H.$V_/_K`%!0XOC__PH`,-7E``!3X_7_
M_PK._/_K``!0X_+__PH%`*#A>_K_ZP!0H.%TH$3B``!5XP4``!H$@)KD``!8
MXU4```H`,-CE``!3XTH``!H%`*#AV_K_ZP"@H.$)`*#AV/K_ZP``BN`!JX#B
M!*"*X@H`H.%8^O_K`("@X=0TG^74%)_E`S"/X``PC>7,-)_E!2"@X0,PC^`!
M$(_@!)"-Y;SZ_^L'':#C"`"@X:?Z_^L!`'#C.@``&J'Z_^L`,)#E$0!3XS8`
M``J4))_EE!2?Y0(`E^<`,(WE`""6Y0@PH.$``)#E`1"/X'WZ_^L`4*#C=!2?
MY40DG^4!$(_@@3R-X@(@D><<,(/B`!"2Y0`@D^4!$#+@`""@XYO__QH%`*#A
M@=R-XB30C>+PC[WHZOO_ZP`P4.(%```*`##3Y0``4^,"```*,_K_ZP!04.*8
M__\:!`"8Y```4./S__\:#%2?Y050C^"2___J"`"@X0H0H.&(^O_K`H"(XI?_
M_^H(`*#A<_S_ZP``4..J__\*"`"@X2#Z_^L`4*#AI/__Z@A0H.&J___J"`"@
MX1`0C>)M^O_K`)!0X@@```JD,Y_EL!.?Y0,`E^<`();E"#"@X0$0C^```)#E
M0OK_Z\/__^H`,13E#SH#X@$)4^/R__\:^%`4Y7KZ_^L``%7A[O__&@`Q%.6#
M.Z#AHSN@X0<-4^/I__\:"@"@X?#Y_^L`4*#A5`.?Y0``C^"L^__K``!0XV$`
M`!H`<);E!P"@X6+Z_^L#`%#C`*"@X1H``)HL$Y_E!`!`X@$0C^```(?@ROG_
MZP``4.,3```:!`!:XP,```H*H(?@!3!:Y2\`4^,-```:!&"6Y0``5N,*```*
M!@"@X4WZ_^L#`%#C!@``FN`2G^4$`$#B`1"/X```AN"V^?_K``!0XP9PH`&T
M_O_K`*!0XG4``!H*$*#A!P"@X=7Y_^L`8%#B<```"@*0H.,`,.#C$2#@XP"0
MC>4$<$3BH/G_ZP8@H.,'$*#A!@"@X07Z_^L$,%3E``!3XS,``!H#,%3E0P!3
MXS```!H",%3E00!3XRT``!H!,%3E0P!3XRH``!H`,-3E2`!3XR<``!H!,-3E
M10!3XR0``!H`,.#C.2#@XP8`H.$`D(WEA?G_ZRD@H.,'$*#A!@"@X>KY_^L(
M(*#A$#*?Y1`2G^4#,(_@!#"-Y0@RG^4`<(WE`S"/X`$0C^`%`*#A`/K_ZP@`
MH.'O^?_K[`&?Y040H.$``(_@$?S_ZP4`H.&5_O_K3?__Z@!PEN65^?_K`!"@
MX0<`H.$,_?_K`'!0XI?__QJ5___J`#"@XP`@H.,`,(WE!@"@X0`PH.-?^?_K
M0P0`ZP"0H.$"*:#C!Q"@X08`H.'"^?_K`"!0XAT``,H&`*#A1&!$XK?Y_^LP
M<$3B"1"@X08`H.&:!`#K!Y"@X5RQG^4+L(_@!P"@X0L0H.$!(-;D`:"*XM+Y
M_^L4`%KC`G"'XO?__QH`,*#C"#!$Y3`QG^4P$9_E`S"/X`0PC>4H,9_E"""@
MX0"0C>4#,(_@`1"/X,#__^H'$*#A"0"@X2\$`.O7___J!!&?Y00!G^4!$(_@
M``"/X-'[_^LR^?_K]#"?Y?00G^4#,(_@"0"-Z.PPG^4((*#A!0"@X0,PC^`!
M$(_@K_G_Z]A`G^788)_EV'"?Y01`C^`&8(_@!W"/X`<=H.,%`*#AE/G_ZP$`
M<..C__\:COG_ZP`PD.41`%/CG___&ACY_^L!D(GB`0*-Z`0PH.$((*#A!A"@
MX04`H.$(<(WEE_G_Z^S__^HT:`$`+`$``&QI`0"<&0``P&<!`*!G`0#=&0``
M/QD``"(9``!<&```#`$``.08```09@$`3A@``#<8``")%P``!A@``+L7``"B
M%P``V!8``&P5```T%0``@14``*X6``#@%0``=!0``/P4``"+%```7A8``)\5
M```D%```#!0``)45```J%@``]T\MZ30SG^4T(Y_E`S"/X`)`D^<``)3E:OG_
MZP!0H.$``)3E9_G_ZV0PU>5E,,#E$`.?Y0``C^"V^O_K``!0XP4```H`,-#E
M,0!3XP(``!H!,-#E``!3XP````I+_?_K``"4Y5?Y_^O<$I_E"S"@XP$@H.,!
M$(_@`?G_ZP``4.,>```:``"4Y4[Y_^N\$I_E`S"@XP$@H.,!$(_@^/C_ZP!0
M4.)-```:``"4Y47Y_^N<$I_E`S"@XP$@H.,!$(_@[_C_ZP!04.)A```*A`*?
MY0``C^"/^O_K`"!0X@0@C>50```*``"4Y3;Y_^L,,)7E!""=Y0`0D^7G^/_K
M5```Z@%0H.,,,)#E3)*?Y1APD^5(HI_E"9"/X`0PF>4``)3E!0!3X0&`1>(&
M``#:)?G_ZP`PH.,((*#A!Q"@X:GX_^L`8%#B!P``&A1BG^4&8(_@!#"6Y0$P
M0^(#`%CAR/__&@%0H.,8``#J"#"9Y0`@EN4%L9/G"#"2Y0HP`^`!"U/C#!"2
M!08```H``)3E#?G_ZP`0EN4",*#C`""@XQ7Y_^L`$*#A"P"@X87X_^L``%#C
MY/__&@%0A>+6___J`?G_ZP<0H.%=^/_K`5"%X@0PEN4``)3E!0!3X??__\JH
M___J``"4Y??X_^L,,)7E="&?Y0`0D^4"((_@I_C_ZPPPE>4`,)/E"#"3Y0$%
M$^.E__\*``"4Y>OX_^L,,)7E`!"3Y7;X_^N?___JK?O_ZP!@4.(``)3E*```
M"N+X_^L,,)7E!B"@X0`0D^63^/_K!@"@X=#X_^L``)3EVOC_ZP!0H.$``)3E
MU_C_Z_P0G^4!(*#C`1"/X#KX_^OP()_E`!"@X0(@C^`%`*#A@_C_ZP``E.7,
M^/_K`#"@XV4PP.70`)_ET$"?Y0``C^`:^O_K!$"/X```4.,,`(3E#@``&@@`
ME.6-_?_K``!0XPP`A.4)```:I`"?Y0``C^`M^/_KN?C_ZY@PG^4#,(_@"""3
MY0PPE>4`()+E?O__ZH1`G^4'':#C!$"/X`P`E.6?^/_K`3"`XA$`4.,!`%,3
M!@``F@`PH.$($)3E7`"?Y0P@E.4`$)'E``"/X!;X_^L,T(WB\(^]Z#AA`0`D
M`0``&Q,``%84```W%```,Q0``$T2``#080$```0@`)AA`0#=$@``9A(``&L2
M``!P$```.&`!`!T2````8`$`Y%\!`.(1``!P0"WI`$"@X3O\_^LS_/_K`%"@
MX0C]_^L``%#C``!4$W"`O0@`,-3E``!3XW"`O0@<$)_E!0"@X0$0C^`G^/_K
M``!5X7"`O1@$`*#A<$"]Z!+Z_^H[$```\$\MZ30KG^4T.Y_E`B"/X%/?3>(#
M,)+G!""-X@+`H.$`,)/E1#&-Y0`PH.-<X(#B'#"`X@00D^0Q'[_F`P!>X000
MC.3Z__\:0,"@XP(0H.$@X)'E-#"1Y00@@N(.,"/@"."1Y0`0D>4.,"/@`3`C
MX.,_H.$!P%SB/#""Y?+__QK`.I_E!)"=Y1!@D.4(()WE@$"0Z-A`P.$#D(G@
M!<`DX&X1).`'$`'@`R""X`:0B>`.P`S@YYV)X`7`+.`%((+@!!`AX`R0B>`"
M$('@9\&@X0P@G>5NH2S@":`*X`,@@N`0@)WE!"""X&ZA*N#I'8'@`J"*X&DA
M+.`!(`+@`X"(X.&MBN`4L)WE81&@X0P@(N!N@8C@""""X&F!(>`#L(O@"H`(
MX`S`B^!I@2C@&+"=Y>HM@N`,@(C@:L$AX`.PB^`"P`S@XHV(X&F1B^!B(:#A
M'+"=Y0'`+.`)P(S@:I$BX`.PB^`(D`G@`1"+X&J1*>`@L)WEZ,V,X`&0B>!H
M$2+@`["+X`P0`>#LG8G@:J&+X&S!H.$DL)WE`A`AX`H0@>!HH2S@`["+X`F@
M"N`"((O@:*$JX"BPG>7I'8'@`J"*X&DA+.`#L(O@`2`"X.&MBN!H@8O@81&@
MX2RPG>4,("+@""""X&F!(>`#L(O@"H`(X`S`B^!I@2C@,+"=Y>HM@N`,@(C@
M:L$AX`.PB^`"P`S@:9&+X`'`+.#BC8C@"<",X&(AH.$TD)WE:K$BX`.0B>`(
ML`O@`1")X&JQ*^`XD)WEZ,V,X`&PB^!H$2+@`Y")X`P0`>#LO8O@:J&)X&S!
MH.$\D)WE`A`AX`H0@>!HH2S@`Y")X`N@"N`"((G@:*$JX$"0G>7K'8'@`J"*
MX&LA+.`#D(G@`2`"X.&MBN!H@8G@81&@X420G>4,("+@""""X&N!(>`#D(G@
M"H`(X&N!*.`,P(G@#,"(X$B`G>7J+8+@:I$AX`.`B.`"D`G@:[&(X`&0*>#B
MS8S@"Y")X&(AH.%,L)WE:H$BX`.PB^`,@`C@:H$HX`$0B^!0L)WE[)V)X`$0
MB.!L@2+@`S"+X`F`".!JH8/@`H`HX!PXG^4*@(C@5*"=Y>D=@>`#H(K@:9&@
MX0(@BN!LH2G@`:`JX`H@@N!8H)WEX8V(X`.@BN!LP8K@8:$IX`B@*N`*P(S@
M7*"=Y>@M@N`#H(K@:(&@X0F0BN!AH2C@`J`JX`J0B>!@H)WEXLV,X`.@BN!A
M$8K@8J$HX`R@*N`*$('@9*"=Y>R=B>`#H(K@;,&@X0B`BN!BH2S@":`JX`J`
MB.!HH)WE;+"=Y0.@BN#I'8'@8B&*X&FA+.#AC8C@`:`JX`.PB^!A$:#A#,"+
MX&FQ(>`(L"O@"[",X'#`G>4*((+@`\",X'2@G>7H+8+@:<&,X&B1(>#BO8O@
M`I`IX`.@BN!B(:#A`1"*X&BA(N`+H"K@"J"!X'@0G>4)P(S@`Q"!X'R0G>7K
MS8S@:!&!X&N!(N#LK8K@#(`HX`.0B>!LP:#A`B")X&N1+.`*D"G@"9""X(`@
MG>4($('@`R""X(2`G>7J'8'@:R&"X&JQ+.#AG8G@`;`KX`.`B.!A$:#A#,"(
MX&J!(>`)@"C@"(",X(C`G>4+((+@`\",X(RPG>7I+8+@:L&,X&FA(>#BC8C@
M`J`JX`.PB^!B(:#A`1"+X&FQ(N`(L"O@"["!X)`0G>4*P(S@`Q"!X.C-C.!I
M$8'@:)$BX`R0*>`)$('@E)"=Y>R]B^`#D(G@;,&@X0(@B>!HD2S@"Y`IX`F0
M@N"8()WEG*"=Y0,@@N#K'8'@:"&"X&N!+.#AG8G@`8`HX`.@BN!A$:#A#*"*
MX&O!(>`)P"S@#*"*X*#`G>4(((+@`\",X.DM@N!KP8S@:;$AX.*MBN`"L"O@
M8B&@X6F!@N%I,0+@"H`(X`O`C.`#@(CAI+"=Y:0UG^7JS8S@`["+X`$0B^`!
M@(C@:A&"X6JQ`N`,$`'@"Q"!X:BPG>7LC8C@`["+X&S!H.%ID8O@"1"!X&J1
MC.%JL0S@")`)X`N0B>&LL)WEZ!V!X`.PB^`"((O@`I")X&@AC.%HL0S@`2`"
MX`L@@N&PL)WEX9V)X`.PB^!A$:#A:J&+X`H@@N!HH8'A:+$!X`F@"N`+H(KA
MM+"=Y>DM@N`#L(O@#,"+X`R@BN!IP8'A:;$!X`+`#.`+P(SAN+"=Y>*MBN`#
ML(O@8B&@X6B!B^`(P(S@:8&"X6FQ`N`*@`C@"X"(X;RPG>7JS8S@`["+X`$0
MB^`!@(C@:A&"X6JQ`N`,$`'@"Q"!X<"PG>7LC8C@`["+X&S!H.%ID8O@"1"!
MX&J1C.%JL0S@")`)X`N0B>'$L)WEZ!V!X`.PB^`"((O@`I")X&@AC.%HL0S@
M`2`"X`L@@N'(L)WEX9V)X`.PB^!A$:#A:J&+X&BQ@>$*((+@";`+X&BA`>`*
ML(OAS*"=Y>DM@N`#H(K@#,"*X`RPB^!IP8'A::$!X`+`#.`*P(SAT*"=Y>*]
MB^`#H(K@8B&@X6B!BN!IH8+A",",X`N@"N!I@0+@"*"*X=2`G>7KS8S@`X"(
MX`$0B.`!H(K@:Q&"X6N!`N`,$`'@"!"!X=B`G>7LK8K@`X"(X&S!H.%ID8C@
M"1"!X&N1C.%K@0S@"I`)X`B0B>'<@)WEZAV!X`.`B.`"((C@`I")X&HAC.%J
M@0S@`2`"X`@@@N'@@)WEX9V)X`.`B.!A$:#A:[&(X`L@@N!JL8'A:H$!X`FP
M"^`(L(OAY("=Y>DM@N`#@(C@#,"(X&F!@>$,L(O@`H`(X&G!`>`,@(CAZ,"=
MY>*]B^`#P(S@8B&@X6JAC.`*@(C@::&"X6G!`N`+H`K@#*"*X>S`G>7KC8C@
M`\",X`$0C.!KP8+A`:"*X`C`#.!K$0+@`<",X?`0G>7HK8K@`S"!X&F1@^`)
MP(S@Q#*?Y?20G>5H@:#A`Y")X`(@B>#X$)WE:Y$HX`J0*>`)D(+@`Q"!X/P@
MG>7JS8S@:Q&!X&JQ*.#LG8G@#+`KX`,@@N!LP:#A"(""X&HA+.`)("+@`H"(
MX``AG>4+$('@`R""X`2QG>7I'8'@:B&"X&FA+.#AC8C@`:`JX`.PB^!A$:#A
M#,"+X&FQ(>`(L"O@"[",X`C!G>4*((+@`\",X`RAG>7H+8+@:<&,X&B1(>#B
MO8O@`I`IX`.@BN!B(:#A`1"*X&BA(N`+H"K@"J"!X!`1G>4)P(S@`Q"!X.O-
MC.!H$8'@:X$BX`R`*.`($('@%(&=Y>RMBN`#@(C@;,&@X0(@B.!K@2S@"H`H
MX`B`@N`8(9WE')&=Y0,@@N#J'8'@:R&"X&JQ+.#AC8C@`;`KX`.0B>!A$:#A
M#,")X&J1(>`(D"G@"9",X"#!G>4+((+@`\",X"2QG>7H+8+@:L&,X&BA(>#B
MG8G@`["+X`*@*N!B(:#A`1"+X&BQ(N`)L"O@"["!X"@1G>4*P(S@`Q"!X.G-
MC.!H$8'@:8$BX`R`*.`($('@+(&=Y>R]B^`#@(C@;,&@X0(@B.!I@2S@"X`H
MX`B`@N`P(9WEZQV!X`,@@N!I(8+@:Y$LX`&0*>`)((+@-)&=Y>&-B.`#D(G@
M81&@X0S`B>!KD2'@")`IX`G`C.`XD9WEZ"V"X`.0B>!KL8G@:)$AX`*0*>`)
ML(O@/)&=Y>+-C.`#D(G@8B&@X0$0B>!HD2+@#)`IX`D0@>!`D9WE[+V+X`,P
MB>`'<(/@:(&'X&QQ(N`+<"?@`B"&X.L=@>`0((#E!X"(X&`@G^7AC8C@1#"?
MY0$0CN!KL83@;,&%X`(@C^``@(#E!!"`Y0BP@.4,P(#E`S"2YP`@D^5$,9WE
M`B`SX``PH.,````*O/7_ZU/?C>+PC[WH5%T!`"P!``"9>8):H>O9;MR\&X_6
MP6+*6%(!`!!`+>E@`*#C,O7_ZR@0G^4H()_E*,"?Y2C@G^4&4(#H)""?Y1`@
M@.4`(*#C%""`Y1@@@.5<((#E$("]Z`$C16>)J\WO_MRZF'94,A#PX=+#\$$M
MZ0)@H.$4,)#E@B&@X0(PD^`8()`E%#"`Y0$@@B(8((`E&#"0Y0!0H.&F/H/@
M&#"`Y5PPD.4<<(#B``!3XQD```I`0&/B!`!6X0,`A^`&0*"Q`0!0X0,``"H$
M,(#@`P!1X0```"KP`/#G`0!0X02`@>`!``":"`!0X?G__SH$(*#A<?7_ZUPP
ME>4#,(3@0`!3XUPPA>7P@;T8!0"@X>O\_^L($*#A!&!&X%R`A>(_`%;C#@``
MR@<`4>$"``":!C"'X`,`4>'F__\Z!P!1X0(``"H&,('@`P!7X>'__SH&(*#A
M!P"@X5CU_^M<8(7E\(&]Z`<`4>$!``":"`!1X=C__SH!`%?A0#"!X@$``)H#
M`%?AT___.@%`H.$'(*#A!!"4Y`,`5.$$$(+D^___&@4`H.'&_/_K0&!&X@00
MH.':___J\$$MZ1R`@>(4,)'E&&"1Y0%`H.%_$.#C,W^_YJ,QH.$_,`/B`2"#
MXC@`4N,`4*#A`Q#(YP(`B.``$*#3-F^_YC@@8M('``#:`!"@XT`@8N*R]/_K
M!`"@X:S\_^LX(*#C`!"@XP@`H.&L]/_K!`"@X?1EQ.&E_/_K`S#4Y00`H.$`
M,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4X04P
MQ>4$,)3E(S2@X08PQ>4$,)3E!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E(S2@
MX0HPQ>4(,)3E"S#%Y0\PU.4,,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,,)3E
M#S#%Y1,PU.40,,7ELC'4X1$PQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y?!!O>CB
M]/_J`4`MZ0%`O>@>_R_A.@```#T````*````/0````\````]````)````#T`
M```R````/0````(````]````!0```#T````3````/0````T````]````#```
M`#T````C````/0```!$````]````)@```#T````!````/0```!<````]````
M"````#T````)````/0``````````````+W1M<`!005)?5$U01$E2`%1%35!$
M25(`5$U0`%5315(`55-%4DY!344`+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O
M=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S
M`&5X90!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/
M0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`4UE35$5-
M`"4P,G@`)7,E<R5S)7,`<&%R+0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`
M<&5R;`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U,`!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO
M=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*
M7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D
M92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D
M<VEZ92`\/2`D8VAU;FM?<VEZ92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I
M9B`H*&UY("1M(#T@)'-I>F4@)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I
M8U]P;W,@/2`D<VEZ92`M("1M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I
M>F4@+2`D8VAU;FM?<VEZ93L*?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2![
M"G-E96LH7T9(+"`D;6%G:6-?<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`]
M(')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S
M("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*
M;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E
M;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@
M("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&
M24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@
M,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*
M?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`
M7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF
M;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO
M<&5N(&UY("1F:"P@)SPG+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D
M("1F:6QE;F%M93H@)"$B.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*
M9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L
M92%<;B(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T
M(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@
M9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]
M"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M
M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O
M+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B
M('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E
M9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X[
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]
M("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L
M(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD
M=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE
M*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@
M0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@
M)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!]
M(&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)
M3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ
M9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]
M("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@)7=R:71T96X["F9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N86UE+"`D9FEL92D["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?.PIL87-T.PI]"F5L<VEF
M("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M
M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H;2%>+VQO861E<B];7B]=
M*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA
M;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0IN97AT('5N;&5S
M<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["FYE
M>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<
M120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG("(I+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT
M96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`]
M(#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N
M86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*
M(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N
M="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O
M;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U
M8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI
M.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P
M-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A
M<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI:
M:7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE
M;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!0
M05(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M(#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<
M)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@
M/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S
M97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?
M0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@
M>PIO<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ
M."P@,CL*<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U
M9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@
M979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z
M.E-(02T^;F5W*#$I.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R
M(&1I92`B8V%N)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H
M.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D[
M"GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G
M/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF
M:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE
M('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P
M=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ
M("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@
M.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN
M:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#([
M"GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD
M7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D
M<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,
M14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*
M?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*
M<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]
M"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@
M9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E
M;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR
M97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!
M4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE
M.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$[
M"E]?14Y$7U\*`'!E<FQX<VDN8P!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(``````Z````/0````H````]````#P```#T````D````/0```#(`
M```]`````@```#T````%````/0```!,````]````#0```#T````,````/0``
M`",````]````$0```#T````F````/0````$````]````%P```#T````(````
M/0````D````]````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````C!<````7```!````5@,```$```!A`P``#P``
M`*T$```,````@!````T```!X/P``&0```,"-`0`;````!````!H```#$C0$`
M'`````0```#U_O]O+`$```4```#4"```!@```!0"```*````RP0```L````0
M````%0`````````#````N(X!``(```#X`0``%````!$````7````B`X``!$`
M``"@#0``$@```.@````3````"````!@`````````^___;P$```CZ__]O$```
M``````````````````````````````````````````````````````#(C0$`
M``````````",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",
M$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0
M``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",$```C!``
M`(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",$```
MC!```(P0``",$```C!```(P0``",$```C!```(P0``",$```C!```(P0``",
M$```C!```(P0``",$```C!```(P0``",$```C!```(P0``"4$P``````````
M``!X/P````````````"`$```````````````````````````````````````
M`````````````)`!`/____\40```/T`````````90```&4$``"1````K00``
M+$`````````P0```-4````````#-0@``1T-#.B`H06QP:6YE(#$P+C(N,5]P
M<F4Q*2`Q,"XR+C$@,C`R,#$R,#,`03(```!A96%B:0`!*`````4V6DL`!@<(
M`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@0B`40!`"YS:'-T<G1A8@`N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+G)E;"YP;'0`
M+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+FEN:71?87)R
M87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````````````
M```````````````````````+`````0````(````4`0``%`$``!@`````````
M``````$`````````$P```/;__V\"````+`$``"P!``#H`````P`````````$
M````!````!T````+`````@```!0"```4`@``P`8```0````#````!````!``
M```E`````P````(```#4"```U`@``,L$``````````````$`````````+0``
M``D````"````H`T``*`-``#H`````P`````````$````"````#8````)````
M0@```(@.``"(#@``^`$```,````0````!`````@````_`````0````8```"`
M$```@!````P```````````````0`````````.@````$````&````C!```(P0
M```(`P`````````````$````!````$4````!````!@```)03``"4$P``Y"L`
M````````````!`````````!+`````0````8```!X/P``>#\```P`````````
M``````0`````````40````$````"````A#\``(0_``!L/@`````````````$
M`````````%D````!`````@```/!]``#P?0``!```````````````!```````
M``!C````#@````,```#`C0$`P(T```0```````````````0````$````;P``
M``\````#````Q(T!`,2-```$```````````````$````!````'L````&````
M`P```,B-`0#(C0``\`````0`````````!`````@```"$`````0````,```"X
MC@$`N(X``$@!``````````````0````$````B0````$````#`````)`!``"0
M```\```````````````$`````````(\````(`````P```#R0`0`\D```,!``
M````````````!`````````"4`````0```#``````````/)```"H`````````
M``````$````!````G0````,``'```````````&:0```S```````````````!
M``````````$````#``````````````"9D```K0```````````````0``````
"````
